@@ -242,9 +242,8 @@ class CollectionCloner:
 
     # Cloning database
     def start_cloning(self, src_db, des_collection):
-        src_docs = src_db[self.src_col].find()
-        for doc in src_docs:
-            try:
-                des_collection.insert(doc)
-            except Exception as e:
-                logger.debug('Could not insert document into destination collection')
\ No newline at end of file
+        src_docs = list(src_db[self.src_col].find())
+        try:
+            des_collection.insert_many(src_docs)
+        except Exception as e:
+            logger.debug('Could not insert document into destination collection')
\ No newline at end of file
